import 'dart:convert';
import 'dart:io';
import 'package:flutter/services.dart' show rootBundle;

class Language {
  static final List<String> languages = [];

  static late Map<String, dynamic> currentLanguage;

  static String getText(String key) {
    return currentLanguage[key] ?? "";
  }

  static Future<void> init(List<String> langs) async {
    languages.addAll(langs);
    final String locale = Platform.localeName;
    try {
      await loadLanguage(locale);
    } catch (e) {
      if (locale != "en_US") await loadLanguage("en_US");
    }
  }

  static Future<void> loadLanguage(String language) async {
    if (!languages.contains(language)) throw Exception("Language not found");
    final String content =
        await rootBundle.loadString("assets/lang/$language.json");
    final Map<String, dynamic> json = jsonDecode(content);
    currentLanguage = json;
    // await SettingsData.settings.set(key: "language", value: language).save();
  }
}
